import { estypes } from '@elastic/elasticsearch';
import { RequestState, QueryConfig, AutocompleteQueryConfig, APIConnector, ResponseState, AutocompleteResponseState } from '@elastic/search-ui';

interface IApiClientTransporter {
    headers: Record<string, string>;
    performRequest(searchRequest: SearchRequest): Promise<ResponseBody>;
}
declare class ApiClientTransporter implements IApiClientTransporter {
    private config;
    headers: Record<string, string>;
    constructor(config: ConnectionOptions);
    private validateConfig;
    performRequest(searchRequest: SearchRequest): Promise<ResponseBody>;
}

type SearchRequest = estypes.SearchRequest;
type ResponseBody = estypes.SearchResponseBody<Record<string, unknown>, Record<string, unknown>>;
type SearchSourceFilter = estypes.SearchSourceFilter;
type SearchHit = estypes.SearchHit<Record<string, unknown>>;
type Filter = Pick<estypes.QueryDslQueryContainer, "bool">;
type FilterValue = Pick<estypes.QueryDslQueryContainer, "term">;
type FilterValueRange = Pick<estypes.QueryDslQueryContainer, "range">;
type QueryRangeValue = estypes.QueryDslRangeQuery;
type Aggregation = estypes.AggregationsTermsAggregateBase<{
    key: string;
    doc_count: number;
}> | estypes.AggregationsMultiBucketAggregateBase<{
    doc_count: number;
}>;
type PostProcessRequestBodyFn = (requestBody: SearchRequest, requestState: RequestState, queryConfig: QueryConfig) => SearchRequest;
type SearchQueryHook<T> = (params: {
    requestBody: SearchRequest;
    requestState: RequestState;
    queryConfig: T;
}, next: (newQueryOptions: SearchRequest) => Promise<ResponseBody>) => Promise<ResponseBody>;
interface CloudHost {
    id: string;
}
type ConnectionOptions = {
    apiClient?: IApiClientTransporter;
    host?: string;
    cloud?: CloudHost;
    index: string;
    apiKey?: string;
    connectionOptions?: {
        headers?: Record<string, string>;
    };
};
type RequestModifiers = {
    interceptSearchRequest?: SearchQueryHook<QueryConfig>;
    interceptAutocompleteResultsRequest?: SearchQueryHook<AutocompleteQueryConfig>;
    interceptAutocompleteSuggestionsRequest?: SearchQueryHook<AutocompleteQueryConfig>;
    getQueryFn?: (state: RequestState, queryConfig: QueryConfig) => SearchRequest;
};

interface ApiProxyConnectorOptions {
    basePath?: string;
    fetchOptions?: RequestInit;
}
declare class ApiProxyConnector implements APIConnector {
    private readonly basePath;
    private readonly fetchOptions;
    constructor({ basePath, fetchOptions }?: ApiProxyConnectorOptions);
    private request;
    onSearch(state: RequestState, queryConfig: QueryConfig): Promise<ResponseState>;
    onAutocomplete(state: RequestState, queryConfig: AutocompleteQueryConfig): Promise<AutocompleteResponseState>;
    onResultClick(): void;
    onAutocompleteResultClick(): void;
}

export { ApiProxyConnector as A, type ConnectionOptions as C, type Filter as F, type IApiClientTransporter as I, type PostProcessRequestBodyFn as P, type QueryRangeValue as Q, type RequestModifiers as R, type SearchRequest as S, type ResponseBody as a, type SearchSourceFilter as b, type SearchHit as c, type FilterValue as d, type FilterValueRange as e, type Aggregation as f, type SearchQueryHook as g, type CloudHost as h, ApiClientTransporter as i };
